summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--officecfg/registry/schema/org/openoffice/Office/Common.xcs2
-rw-r--r--sc/qa/unit/subsequent_export_test2.cxx14
2 files changed, 12 insertions, 4 deletions
diff --git a/officecfg/registry/schema/org/openoffice/Office/Common.xcs b/officecfg/registry/schema/org/openoffice/Office/Common.xcs
index 16d069ffd93a..73b1acbe871d 100644
--- a/officecfg/registry/schema/org/openoffice/Office/Common.xcs
+++ b/officecfg/registry/schema/org/openoffice/Office/Common.xcs
@@ -1499,7 +1499,7 @@
page through the objects since they do not always need to be loaded
from the hard drive.</desc>
</info>
- <value>20</value>
+ <value>200</value>
</prop>
</group>
<group oor:name="Writer">
diff --git a/sc/qa/unit/subsequent_export_test2.cxx b/sc/qa/unit/subsequent_export_test2.cxx
index 77b8858fcd97..fa55acdf5160 100644
--- a/sc/qa/unit/subsequent_export_test2.cxx
+++ b/sc/qa/unit/subsequent_export_test2.cxx
@@ -2696,9 +2696,17 @@ void ScExportTest2::testHyperlinkLocationXLSX()
void ScExportTest2::testTdf142264ManyChartsToXLSX()
{
// The cache size for the test should be small enough, to make sure that some charts get
- // unloaded in the process, and then loaded on demand properly (default is currently 20)
- CPPUNIT_ASSERT_LESS(sal_Int32(40),
- officecfg::Office::Common::Cache::DrawingEngine::OLE_Objects::get());
+ // unloaded in the process, and then loaded on demand properly (default is currently 200)
+ comphelper::ScopeGuard g([]() {
+ std::shared_ptr<comphelper::ConfigurationChanges> pBatch(
+ comphelper::ConfigurationChanges::create());
+ officecfg::Office::Common::Cache::DrawingEngine::OLE_Objects::set(200, pBatch);
+ return pBatch->commit();
+ });
+ std::shared_ptr<comphelper::ConfigurationChanges> pBatch(
+ comphelper::ConfigurationChanges::create());
+ officecfg::Office::Common::Cache::DrawingEngine::OLE_Objects::set(20, pBatch);
+ pBatch->commit();
ScDocShellRef xDocSh = loadDoc(u"many_charts.", FORMAT_ODS);
xDocSh = saveAndReload(*xDocSh, FORMAT_XLSX);